%define aurox_ver 10.2
%define rel 2

Summary: The Linux kernel (the core of the Linux operating system)

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.

%define buildup 1
%define buildsmp 1
%define buildsource 1


# Versions of various parts

#
# Polite request for people who spin their own kernel rpms:
# please modify the "release" field in a way that identifies
# that the kernel isn't the stock distribution kernel, for example by
# adding some text to the end of the version number.
#
%define sublevel 9
%define kversion 2.6.%{sublevel}
%define rpmversion 2.6.%{sublevel}
%define rhbsys  %([ -r /etc/beehive-root ] && echo  || echo .`whoami`)
#define release %(R="$Revision: 1.358 $"; RR="${R##: }"; echo ${RR%%?})%{rhbsys}
#define release %(svn info kernel.spec | grep 'Last Changed Rev' | cut -d ':' -f 2)%{rhbsys}
%define release %{aurox_ver}.aur.%{rel}

%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}

# groups of related archs
%define all_x86 i386 i586 i686 athlon

# Override generic defaults with per-arch defaults 

# First, architecture-specific kernels off on all other archs (ifnarch)
%ifarch i686 i586 athlon
%define buildsource 0
%endif

# Second, per-architecture exclusions (ifarch)
%ifarch i386
%define buildsmp 0
%define buildup 0
%endif

%ifarch i586
%define buildsmp 0
%endif

%ifarch %{all_x86}
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-i?86*.config $RPM_SOURCE_DIR/kernel-%{kversion}-athlon*.config
%endif

%ifarch x86_64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-x86_64*.config
%endif

%ifarch ppc64pseries ppc64iseries
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64*.config
%endif

%ifarch s390
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-s390.config
%endif

%ifarch s390x
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-s390x.config
%endif

%ifarch sparc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc.config
%define buildsmp 0
%endif
                                                                                                                   
%ifarch sparc64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-sparc64*.config
%endif

%ifarch ppc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc.config
%define buildsmp 0
%endif

%ifarch ia64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ia64.config
%define buildsmp 0
%endif

#
# IA64 wants to be different as usual.. sigh.
#
%ifarch ia64
%define image_install_path boot/efi/EFI/redhat
%else
%define image_install_path boot
%endif




#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp <= 2.3.15, pcmcia-cs <= 3.1.20, isdn4k-utils <= 3.0, mount < 2.10r-5, nfs-utils < 1.0.3, e2fsprogs < 1.29, util-linux < 2.10, jfsutils < 1.0.14, reiserfsprogs < 3.6.3, xfsprogs < 2.1.0, procps < 2.0.9, oprofile < 0.5.3

# 
# Then a series of requirements that are distribution specific, either 
# because we add patches for something, or the older versions have 
# problems with the newer kernel or lack certain things that make 
# integration in the distro harder than needed.
#
%define package_conflicts  cipe < 1.4.5, tux < 2.1.0, kudzu <= 0.92, initscripts < 7.23, dev < 3.2-7, iptables < 1.2.5-3, bcm5820 < 1.81, nvidia-rh72 <= 1.0

#
# Several packages had bugs in them that became obvious when the NPTL
# threading code got integrated. 
#
%define nptl_conflicts SysVinit < 2.84-13, pam < 0.75-48, vixie-cron < 3.0.1-73, privoxy < 3.0.0-8, spamassassin < 2.44-4.8.x,  cups < 1.1.17-13

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools, initscripts >= 7.53-10.0.aur.1, mkinitrd >= 3.5.22

Name: kernel
Group: System Environment/Kernel
License: GPLv2
Version: %{rpmversion}
Release: %{release}
#ExclusiveArch: %{all_x86} x86_64 ppc64pseries ppc64iseries s390 s390x sparc sparc64 ppc ia64
ExclusiveArch: %{all_x86} x86_64 ppc64pseries ppc64iseries sparc sparc64 ppc ia64
ExclusiveOS: Linux
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: alsa-driver
Obsoletes: alsa-driver
Provides: kernel-module-alsa
Provides: kernel-ntfs
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no

#
# List the packages used during the kernel build
#
BuildPreReq: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildPreReq: bzip2, findutils, gzip, m4, perl, make >= 3.78, gnupg, kernel-utils
BuildRequires: gcc >= 2.96-98, binutils >= 2.12, redhat-rpm-config
BuildConflicts: rhbuildsys(DiskFree) < 500Mb



Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{kversion}.tar.bz2

Source10: COPYING.modules

# TODO: sync with i686:
#Source20: kernel-%{kversion}-i586.config
#Source21: kernel-%{kversion}-i586-smp.config
Source22: kernel-%{kversion}-i686.config
#Source23: kernel-%{kversion}-i686-smp.config

# Not supported:
#Source24: kernel-%{kversion}-x86_64.config
#Source25: kernel-%{kversion}-x86_64-smp.config
#Source26: kernel-%{kversion}-ppc64pseries.config
#Source27: kernel-%{kversion}-ppc64iseries.config
#Source28: kernel-%{kversion}-s390.config
#Source29: kernel-%{kversion}-s390x.config
#Source30: kernel-%{kversion}-sparc.config
#Source32: kernel-%{kversion}-sparc64.config
#Source33: kernel-%{kversion}-sparc64-smp.config
#Source34: kernel-%{kversion}-ppc.config
#Source35: kernel-%{kversion}-ia64.config


#
# Patches 0 through 100 are meant for core subsystem upgrades
#
#Patch1: patch-2.6.6-rc3.bz2
#Patch2: patch-2.6.6-rc3-bk3.bz2
#Patch3: patch-2.6.7-rc3.bz2
#Patch4: patch-2.6.7-rc3-bk6.bz2
Patch5: patch-2.6.9-ac16.bz2
Patch6: linux-2.6.9-selected-ac-bits.patch
Patch7: linux-2.6.9-ac-backouts.patch

# Post-2.6 upgrades to drivers

# Patches 100 through 500 are meant for architecture patches

# 200 - 300   x86(-64)

# Not in Aurox:
#Patch200: linux-2.6.5-nostack.patch

# 300 - 330   ppc64
# Not in Aurox:
#Patch300: linux-2.6.2-ppc64-build.patch

#
# 330 - 350   ia64
#
# Not in Aurox:
#Patch330: linux-2.6.3-ia64-build.patch
#Patch340: linux-2.6.5-discontigmemoption.patch

# 350 - 400   s390(x)
# Not in Aurox:
#Patch350: linux-2.6.1-s390-compile.patch

#
# 400 - sparc(64)
#
# Not in Aurox:
#Patch400: linux-2.6.3-sparc-addbzimage.patch

#
# Patches 500 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#

Patch500: linux-2.4.0-nonintconfig.patch
Patch510: linux-2.6.8-flexmmap-x86-64.patch
Patch511: linux-2.6.0-exec-shield.patch
Patch512: linux-2.6.8-print-fatal-signals.patch
Patch513: linux-2.6.8-execshield-vaspace.patch


#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#

Patch1000: linux-2.4.0-test11-vidfail.patch
Patch1020: linux-2.6.4-stackusage.patch
Patch1030: linux-2.6.5-ext3-reservations.patch
Patch1031: linux-2.6.8-ext3-reservations-update.patch
Patch1040: linux-2.6.5-ext3-online-resize.patch
Patch1050: linux-2.6.7-devmem.patch
Patch1051: linux-2.6.0-devmem.patch
Patch1060: linux-2.6.3-crash-driver.patch
Patch1070: linux-2.6.0-sleepon.patch
# TODO: check and fix
Patch1080: linux-2.6.7-i8x0-drm.patch
Patch1090: linux-2.6.5-fb.patch
Patch1110: linux-2.6.9-irqfixup.patch
Patch1120: linux-2.6.7-scsi-whitelist.patch
Patch1140: linux-2.6.9-blockfixes.patch
Patch1150: linux-2.6.9-sata.patch
Patch1160: linux-2.6.9-scsi-megaraid-legacy.patch

Patch2000: linux-2.6.3-printopen.patch
Patch2010: linux-2.6.9-xattr-rework-tmpfs-mm.patch

#Patch2020: linux-2.6.9-O_NONBLOCK.patch

Patch2030: linux-2.6.9-cdrom_buffer_size.patch
Patch2040: linux-2.6.9-ext3_umount_hang.patch
Patch2050: linux-2.6.9-nvidia_lapic_hang.patch

#
# External drivers that are about to get accepted upstream
#

# patches 5000 to 6000 are new drivers included in Aurox
Patch5000: linux-2.6.9-dvd+rw.patch
Patch5001: linux-2.6.9-dvd+rw-credits.patch
Patch5002: linux-2.6.9-packet_writing.patch
#Patch5100: ipw2100-2.6.8-patch 
#Patch5101: kernel-ipw2100-0.56.patch
Patch5102: ipw2x00.patch

# Software Suspend 2 -- should be well in the beginning: TODO
Patch5500: software-suspend-2.1-for-2.6.9.patch


#
# 10000 to 20000 is for stuff that has to come last due to the
# amount of drivers they touch. But only theese should go here. 
# Not patches you're too lazy for to put in the proper place.
#

# Apply as needed:
Patch10000: linux-2.6.7-compile.patch
# Patch10010: linux-2.6.0-module-license.patch
Patch10020: linux-2.6.9-percpu_fixup.patch
Patch10030: linux-2.6.9-gcc-3.4_qla2xxx.patch
Patch10040: linux-2.6.9-nvidia_compat.diff

# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

%description 
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.


%package source
Summary: The source code for the Linux kernel.
Group: Development/System
Prereq: fileutils
Requires: make >= 3.78
Requires: gcc >= 3.2
Requires: /usr/bin/strip
# for xconfig and gconfig
Requires: qt-devel, gtk2-devel readline-devel ncurses-devel

%description source
The kernel-source package contains the source code files for the Linux
kernel. The source files can be used to build a custom kernel that is
smaller due only including drivers for your particular hardware, if you are
so inclined (and you know what you're doing). The customisation guide in the
documentation describes in detail how to do this. This package is neither
needed nor usable for building external kernel modules for linking into the
default kernel.

%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation

%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files. 

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package smp
Summary: The Linux kernel compiled for SMP machines.

Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: alsa-drive
Obsoletes: alsa-driver
Provides: kernel-smp-module-alsa
Provides: kernel-ntfs-smp
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# upto and including kernel 2.4.9 rpms, the 4Gb+ kernel was called kernel-enterprise
# now that the smp kernel offers this capability, obsolete the old kernel
Obsoletes: kernel-enterprise < 2.4.10
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no

%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs as well as machines with
hyperthreading technology.

Install the kernel-smp package if your machine uses two or more CPUs.

%prep

%setup -q -n %{name}-%{version} -c
cd linux-%{kversion}

#
# Patches 0 through 100 are meant for core subsystem upgrades
# 

# update to recent upstream bk snapshot

#%patch1 -p1
#%patch2 -p1
#%patch3 -p1
#%patch4 -p1
# Some bits from -ac
%patch5 -p1
%patch6 -p1
%patch7 -p1 -R

#
# Architecture patches
#
#
# x86(-64)
#
#%patch200 -p1


# 
# ppc64
#

# Patch for Kconfig and Makefile build issues
#%patch300 -p1


#
# ia64
#

# Basic build fixes
#%patch330 -p1

#
# Make DISCONTIGMEM an option again
#
#%patch340 -p1

#
# s390
#

# Basic build fixes
#%patch350 -p1

#
# sparc/sparc64
#
#%patch400 -p1
#
# Patches 500 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#


# This patch adds a "make nonint_oldconfig" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the buildsystem).
%patch500 -p1

#
# The execshield patch series, broken into smaller pieces
#
# 1) Flexible mmap patch
#
%patch510 -p1

# 2) Exec shield core
#
%patch511 -p1

# 3) Option to printk fatal signals, useful for debugging
#
%patch512 -p1

# 4) The Execshield VA rearrangements
#
%patch513 -p1

#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#

# add vidfail capability; 
# without this patch specifying a framebuffer on the kernel prompt would
# make the boot stop if there's no supported framebuffer device; this is bad
# for the installer cd that wants to automatically fall back to textmode
# in that case
%patch1000 -p1

#
# Fix the extreme stack usage in some kernel functions
#
#%patch1020 -p1

#
# Ext3 reservations. reduces fragmentation bigtime
#
%patch1030 -p1
%patch1031 -p1

#
# ext3 online resize
#
%patch1040 -p1

#
# Make /dev/mem a need-to-know function 
#
%patch1050 -p1
%patch1051 -p1

#
# /dev/crash driver for the crashdump analysis tool
#
%patch1060 -p1

#
# Most^WAll users of sleep_on are broken; fix a bunch
#
%patch1070 -p1

#
# Fix i8x0 DRM errors
#
#%patch1080 -p1

#
# FB code is evil 
#
#%patch1090 -p1 

#
# Alan's patch to make the irq code more robust against broken BIOSes
#
#%patch1110 -p1

#
# Restore old megaraid module
#
%patch1160 -p1

#
# Local hack (off for any shipped kernels) to printk all files opened 
# the first 180 seconds after boot for debugging userspace startup 
# speeds
#
# %patch2000 -p1

#
# SELinux xattr for tmpfs (from 2.6.9-mm)
#
%patch2010 -p1

#
# support O_NONBLOCK for read,pread,readv of regular files
#
#%patch2020 -p1

#
# Fix ext3 umount hang
#
%patch2040 -p1

#
# Fix APIC/LAPIC hanging problems on nForce2 systems
#
%patch2050 -p1

#
# Patches 5000 to 6000 are reserved for new drivers that are about to
# be merged upstream
#

#
# DVD+RW support and CD-RW packet writing
#
%patch5000 -p1
%patch5001 -p1
%patch5002 -p1

#
# cdrom: buffer sizing fix
#
%patch2030 -p1

#
# Intel PRO/Wireless 2100 802.11b Driver for Linux
# Intel PRO/Wireless 2200 802.11bg Driver for Linux
#
#%patch5100 -p1
#%patch5101 -p1
%patch5102 -p1

#
# Software Suspend 2
#
%patch5500 -p1

#
# final stuff
#

#
# misc small stuff to make things compile or otherwise improve performance
#
#%patch10000 -p1
%patch10020 -p1
%patch10030 -p1
%patch10040 -p1

# END OF PATCH APPLICATIONS

cp %{SOURCE10} Documentation/

mkdir configs

cp -fv %{all_arch_configs} .

# now run oldconfig over all the config files
for i in *.config 
do 
	mv $i .config 
	make nonint_oldconfig > /dev/null 
	mv .config configs/$i 
done

# make sure the kernel has the sublevel we know it has. This looks weird
# but for -pre and -rc versions we need it since we only want to use
# the higher version when the final kernel is released.
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -prep/" Makefile

# get rid of unwanted files resulting from patch fuzz
find . -name "*.orig" -exec rm -fv {} \;
find . -name "*~" -exec rm -fv {} \;

###
### build
###
%build

cd linux-%{kversion}

BuildKernel() {

    # Pick the right config file for the kernel we're building
    if [ -n "$1" ] ; then
	Config=kernel-%{kversion}-%{_target_cpu}-$1.config
    else
	Config=kernel-%{kversion}-%{_target_cpu}.config
    fi

    KernelVer=%{version}-%{release}$1
    echo BUILDING A KERNEL FOR $1 %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$1/" Makefile

    # and now to start the build process

    make -s mrproper
    cp configs/$Config .config

    make -s nonint_oldconfig > /dev/null
#    make -s include/linux/version.h 

#    make -s %{?_smp_mflags} bzImage 
#    make -s %{?_smp_mflags} modules || exit 1
    make %{?_smp_mflags} || exit 1
    make buildcheck
    
    # Start installing the results

    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/boot
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 System.map $RPM_BUILD_ROOT/usr/lib/debug/boot/System.map-$KernelVer
    objdump -t vmlinux | grep ksymtab | cut -f2 | cut -d" " -f2 | cut -c11- | sort -u  > exported
    echo "_stext" >> exported
    echo "_end" >> exported
    touch $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    for i in `cat exported` 
    do 
	 grep " $i\$" System.map >> $RPM_BUILD_ROOT/boot/System.map-$KernelVer || :
	 grep "tab_$i\$" System.map >> $RPM_BUILD_ROOT/boot/System.map-$KernelVer || :
	 grep "__crc_$i\$" System.map >> $RPM_BUILD_ROOT/boot/System.map-$KernelVer ||:
    done
    rm -f exported
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    rm -f System.map
    cp arch/*/boot/bzImage $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer
 
    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files 

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # first copy everything
    cp --parents `find  -type f -name Makefile -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build 
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp arch/%{_arch}/kernel/asm-offsets.s $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/kernel || :
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a acpi config linux math-emu media net pcmcia rxrpc scsi sound video asm asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp -a `readlink asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    cd .. 

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer

    # mark modules executable so that strip-to-file can strip them
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f  | xargs chmod u+x

    # detect missing or incorrect license tags
    for i in `find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" ` ; do echo -n "$i " ; /sbin/modinfo -l $i >> modinfo ; done
    cat modinfo | grep -v "^GPL" | grep -v "^Dual BSD/GPL" | grep -v "^Dual MPL/GPL" | grep -v "^GPL and additional rights" | grep -v "^GPL v2" && exit 1 
    rm -f modinfo
    # remove files that will be auto generated by depmod at rpm -i time
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.*

}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

%if %{buildup}
BuildKernel
%endif

%if %{buildsmp}
BuildKernel smp
%endif

###
### install
###

%install

cd linux-%{kversion}

# architectures that don't get kernel-source (i586/i686/athlon) dont need
# much of an install because the build phase already copied the needed files

%if %{buildsource}

mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

# clean up the source tree so that it is ready for users to build their own
# kernel
make -s mrproper

# copy the source over
tar cf - . | tar xf - -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

# set the EXTRAVERSION to <version>custom, so that people who follow a kernel building howto
# don't accidentally overwrite their currently working moduleset and hose
# their system
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}custom/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/Makefile
install -m 644 %{SOURCE10}  $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

# load the loop module for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%pre 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%post 
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}
[ -x /usr/sbin/hardlink ] && /usr/sbin/hardlink -c /lib/modules/2.6.* || :
# remove hdX=ide-scsi when upgrading from 2.4 kernels, booty doesn't handle this correctly
[ -x /bin/sed ] && [ -f /boot/grub/grub.conf ] && /bin/sed -i -e "s/\(vmlinuz-%{version}-%{release}.*\) hd.=ide-scsi\(.*\)/\1\2/" /boot/grub/grub.conf

%post smp
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}smp
[ -x /usr/sbin/hardlink ] && /usr/sbin/hardlink -c /lib/modules/2.6.* || :
# remove hdX=ide-scsi when upgrading from 2.4 kernels, booty doesn't handle this correctly
[ -x /bin/sed ] && [ -f /boot/grub/grub.conf ] && /bin/sed -i -e "s/\(vmlinuz-%{version}-%{release}.*\) hd.=ide-scsi\(.*\)/\1\2/" /boot/grub/grub.conf

%preun 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}

%preun smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp


###
### file lists
###

%if %{buildup}
%files 
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}
/boot/System.map-%{KVERREL}
/boot/config-%{KVERREL}
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/kernel
%verify(not mtime) /lib/modules/%{KVERREL}/build

%endif

%if %{buildsmp}
%files smp
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
/boot/config-%{KVERREL}smp
%dir /lib/modules/%{KVERREL}smp
/lib/modules/%{KVERREL}smp/kernel
%verify(not mtime) /lib/modules/%{KVERREL}smp/build

%endif

# only some architecture builds need kernel-source and kernel-doc

%if %{buildsource}

%files source
%defattr(-,root,root)
/usr/src/linux-%{KVERREL}/

%files doc
%defattr(-,root,root)
%doc linux-%{kversion}/Documentation/*

%endif

%changelog
* Wed Feb 09 2005 Aurox Team <aurox@aurox.org> 0:2.6.9-10.2.aur.2
- Update ipw2100 to 1.0.3 and ipw2200 to 1.0.0 (the latter needs 2.2 firmware).
- Add more bits from 2.6.10-ac series (January security fixes).
- Fix nForce2 APIC hangs.
- Restore old megaraid module.
- Fix ext3 umount hang.
- Rebase against 2.6.9-ac16, this fixes a number of bugs, including a nasty one in the OOM code.
- Merge bits from -ac kernels.

* Thu Nov 11 2004 Aurox Team <aurox@aurox.org> 0:2.6.9-10.1.aur.4
- Update swsusp2 to 2.1.5.
- Fix binfmt_elf bug.
- Add Intel PRO/Wireless 2200 802.11bg Driver for Linux 0.12.
- Fold the ipw2x00 drivers into a single patch.
- Update to swsusp 2.1.4.
- Readd hdX=ide-scsi removal.
- Fix incorrect Mt Rainier detection.
- Fix i8xx_tco watchdog causing reboots.
- Export __VMALLOC_RESERVE to make nVidia modules compile.
- Update DVD+RW / packet writing patches.
- Update swsusp2 to 2.1.
- Update ipw2100 to 0.56 (needs v1.3 firmware).
- Update external patches.
- Update exec shield patches.
- Rebase against 2.6.9.
- Remove ide-scsi hacks, booty should handle this by now.
- Upgrade to ipw2100-0.51 (ipw2100-firmware-1.2 needed)
- obsoletes: kernel-module-alsa, kernel-module-ntfs
- SMP/UP separation take two, .configs modified.
- Separate SMP and UP builds, take one.
- i8x0 DRM fix
- Remove hdX=ide-scsi leftover in postinstall
- Fix oops on Centrino
- Add swsusp2 2.6.7-rev4/2.0.0.90
- Add ipw2100-0.49 to the build
- Security fixes
- Fix denial of service in tcp_find_option()
- Merge ALSA CVS as of 2004-05-31 (1.0.5a)
- Compile for Athlon
- Remove SCSI debug
- Disable vdso in exec-shield
- Add i586
- upgrade to 2.6.7-final
- readd exec-shield-nx-2.6.7-A0
- modify kernel.spec to account for kbuild changes: single invocation of make
- drop linux-2.6.7-compile.patch, not needed
- remove bk patch; build 2.6.7-rc3
- update to 2.6.7-rc3-bk6
- add packet writing patch for CD-RW
- remove references to use_nx from exec-shield patch
- adapt exec-shield patch
- build 2.6.7-rc3-bk5
- disable PM_DISK
- Enable BLK_DEV_OFFBOARD and ide-scsi modules
- Remove outdated config options
- most of the compile patch removed (not needed?)
- remove exec-shield for this build until it is merged with our changes
- update exec-shield using exec-shield-on-nx-2.6.7-rc2-bk2-A9
- Update to patch-2.6.7-rc2-bk7
- Enable PM_DISK (the new software suspend fork)
- Enable two more sound drivers modules: SND_SERIAL_U16550 and SND_WAVEFRONT
- set SMB_NLS_DEFAULT to "cp437"
- update config options in 2.6.7-rc2, enabling all Gigabit drivers
- no need to patch ALSA
- update to 2.6.7-rc2
- rebuild as preemptible kernel (CONFIG_PREEMPT=y)
- rebuild with SECURITY_CAPABILITIES set to 'm'
- build doc and source too
- build with fixed exec-shield and latest ALSA
- fix exec shield patch
- update config for 2.6.7-rc1
- make exec shield patch apply on 2.6.7-rc1
- update to 2.6.7-rc1
- enable NTFS RW suppport
- update to bk8 snapshot
- update ASLA drivers to post-1.0.4 CVS - from mm4 patch set
- rebuild for Aurox 10
- remove patches not applied on Aurox
- use exec-shield updated for 2.6.6; remove offending arch/s390/kernel/binfmt_elf32.c
- import kernel 2.6

* Sat May 08 2004 Arjan van de Ven <arjanv@redhat.com>
- fix non-booting on Transmeta cpus (Peter Arvin)
- fix count leak in message queues

* Fri May 07 2004 Arjan van de Ven <arjanv@redhat.com>
- more ide cache flush work
- patch from scsi-bk to fix sd refcounting

* Thu May 06 2004 Arjan van de Ven <arjanv@redhat.com>
- some more ide cache flush fixes 

* Wed May 05 2004 Arjan van de Ven <arjanv@redhat.com>
- fix bug 122504
- convert b44 to ethtool ops (jgarzik)
- make IDE do a cache-flush on shutdown (me/Alan)

* Tue May 04 2004 Arjan van de Ven <arjanv@redhat.com>
- work around i810/i830 DRM issue

* Fri Apr 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc3-bk1
- make amd64 boot again
- fix vm86-vs-4g4g interaction (Ingo)

* Thu Apr 22 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc2
 
* Tue Apr 20 2004 Arjan van de Ven <arjanv@redhat.com>
- add the ext3 online resize patch

* Mon Apr 19 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc1-bk3
- add the objrmap vm from the -mm tree; it needs testing

* Thu Apr 15 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-bk2
- disable DISCONTIGMEM on ia64 for performance
- fix sleep_on use in reiserfs (Chris Mason)

* Tue Apr 13 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-mc4
- reenable sg driver for scsi tape changers and such
- the sk98lin driver oopses on module unload, preven that

* Mon Apr 12 2004 Arjan van de Ven <arjanv@redhat.com>
- fix "bad pmd" bug with patch from Ingo

* Fri Apr 09 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-mc3
- finish up the -mc2 merge
- latest 4g/4g patch from Ingo
- latest execshield patch from Ingo
- fix a few framebuffer bugs

* Thu Apr 08 2004 Arjan van de Ven <arjanv@redhat.com>
- first attempt at a 2.6.5-mc2 merge

* Thu Apr 08 2004 Dave Jones <davej@redhat.com>
- Add in missing SiS AGP fix.

* Tue Apr 06 2004 Dave Jones <davej@redhat.com>
- More agpgart fixes.

* Fri Apr 02 2004 Arjan van de Ven <arjanv@redhat.com>
- fix another 4g/4g-vs-resume bug

* Tue Mar 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc3
- fix PCI posting bug in i830 DRM

* Mon Mar 29 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk8

* Mon Mar 29 2004 Dave Jones <davej@redhat.com>
- Include latest agpgart fixes.

* Thu Mar 25 2004 Arjan van de Ven <arjanv@redhat.com>
- more DRM fixes
- add the fsync patches from akpm

* Tue Mar 23 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk3
- fix direct userspace memory access in i830 drm driver

* Mon Mar 22 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk2
- some stackbloat reductions from Dave and me

* Sat Mar 20 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2

* Tue Mar 16 2004 Dave Jones <davej@redhat.com>
- 2.6.5-rc1

* Mon Mar 15 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-bk3
- fix oops in toshiba_acpi (Barry K. Nathan)

* Sat Mar 13 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-bk2 merge 

* Thu Mar 11 2004 Arjan van de Ven <arjanv@redhat.com>
- renable sonypi driver that was off accidentally
- 2.6.4-final 
- fix the oops on alsa module unloads

* Wed Mar 10 2004 Arjan van de Ven <arjanv@redhat.com>
- add ppc64/iseries, ppc32 (powermac/ibook) and ia64 architectures
- 2.6.4-rc3 

* Tue Mar 09 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-rc2-bk5
- fix nfs-vs-selinux issue
- fix typo in URL as per #117849

* Mon Mar 08 2004 Arjan van de Ven <arjanv@redhat.com>
- fix race in lp.c (#117710)
- 2.6.4-rc2-bk3
- attempt to fix S3 suspend-to-ram with 4g/4g split

* Sat Mar 06 2004 Arjan van de Ven <arjanv@redhat.com>
- fix reiserfs
- set HZ to 1000 again for some tests

* Wed Feb 25 2004 Arjan van de Ven <arjanv@redhat.com>
- merge back a bunch of fedora fixes
- disable audit

* Tue Feb 24 2004 Arjan van de Ven <arjanv@redhat.com>
- audit bugfixes
- update tux to a working version
- 2.6.3-bk5 merge

* Fri Feb 20 2004 Arjan van de Ven <arjanv@redhat.com>
- re-add and enable the Auditing patch
- switch several cpufreq modules to built in since detecting in userspace
  which to use is unpleasant
* Thu Jul 03 2003 Arjan van de Ven <arjanv@redhat.com>
- 2.6 start 
 
